@@ -1,5 +1,5 @@
+from . import base
 from . import beautifulsoup
-from . import data_types
 from . import geopandas
 from . import pandas
 from . import psycopg2
@@ -7,3 +7,7 @@ from ._version import get_versions
 
 __version__ = get_versions()['version']
 del get_versions
+
+from ._version import get_versions
+__version__ = get_versions()['version']
+del get_versions
